==> jc-1.4.0.tar.gz: java/lang/reflect/Modifier.h <==
// public class java.lang.reflect.Modifier

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b413af5dc930e175 java_lang_reflect_Modifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Modifier_H_
#define _JC_java_lang_reflect_Modifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Modifier$sub_refs	_jc_java_lang_reflect_Modifier$sub_refs;
typedef struct _jc_java_lang_reflect_Modifier$sub_nonrefs	_jc_java_lang_reflect_Modifier$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Modifier$refs	_jc_java_lang_reflect_Modifier$refs;
typedef struct _jc_java_lang_reflect_Modifier$nonrefs	_jc_java_lang_reflect_Modifier$nonrefs;
typedef struct _jc_java_lang_reflect_Modifier$object	_jc_java_lang_reflect_Modifier$object;

typedef struct _jc_java_lang_reflect_Modifier$fields_struct	_jc_java_lang_reflect_Modifier$fields_struct;
typedef const struct _jc_java_lang_reflect_Modifier$vmethods	_jc_java_lang_reflect_Modifier$vmethods;
typedef const struct _jc_java_lang_reflect_Modifier$vtable	_jc_java_lang_reflect_Modifier$vtable;
typedef const struct _jc_java_lang_reflect_Modifier$vtype	_jc_java_lang_reflect_Modifier$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Modifier$fields_struct {
	jint	ABSTRACT;
	jint	ALL__5fFLAGS;
	jint	FINAL;
	jint	INTERFACE;
	jint	NATIVE;
	jint	PRIVATE;
	jint	PROTECTED;
	jint	PUBLIC;
	jint	STATIC;
	jint	STRICT;
	jint	SUPER;
	jint	SYNCHRONIZED;
	jint	TRANSIENT;
	jint	VOLATILE;
};
extern _jc_java_lang_reflect_Modifier$fields_struct _jc_java_lang_reflect_Modifier$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Modifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_Modifier$object *);

// Static methods
extern jboolean _jc_java_lang_reflect_Modifier$method$isAbstract$1cd5ca6bb91d8ecc(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isFinal$8e8ef7d449c3f86e(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isInterface$8c444522b1e3c146(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isNative$66f628b5ecbea9d8(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isPrivate$261685c1800e143b(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isProtected$bb52b8e24e56f1b6(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isPublic$78f9198c5d44531f(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isStatic$11ab11e4d169860e(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isStrict$423f1a01334d10a3(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isSynchronized$b02482e04be5cf74(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isTransient$eed6a1a278d70a1a(_jc_env *, jint);
extern jboolean _jc_java_lang_reflect_Modifier$method$isVolatile$406ed47e0f5f48d4(_jc_env *, jint);
extern struct _jc_java_lang_String$object *_jc_java_lang_reflect_Modifier$method$toString$1edd17eb26e44570(_jc_env *, jint);
extern struct _jc_java_lang_StringBuffer$object *_jc_java_lang_reflect_Modifier$method$toString$e0ef92f7f91b1ef9(_jc_env *, jint, struct _jc_java_lang_StringBuffer$object *);

// Virtual methods structure
struct _jc_java_lang_reflect_Modifier$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_Modifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Modifier$vmethods	java_lang_reflect_Modifier;
};

// Vtype
struct _jc_java_lang_reflect_Modifier$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Modifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Modifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Modifier$refs {
    _jc_java_lang_reflect_Modifier$sub_refs	java_lang_reflect_Modifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Modifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Modifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Modifier$sub_nonrefs	java_lang_reflect_Modifier;
};

// Object instance structure
struct _jc_java_lang_reflect_Modifier$object {
	_jc_java_lang_reflect_Modifier$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Modifier$vtype	*vtype;
	_jc_java_lang_reflect_Modifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Modifier$vtype _jc_java_lang_reflect_Modifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Modifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Modifier$class_object;

#endif	/* _JC_java_lang_reflect_Modifier_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/Modifier.h <==
// public class java.lang.reflect.Modifier

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b413af5dc930e175 java_lang_reflect_Modifier

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Modifier_H_
#define _JC_java_lang_reflect_Modifier_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Modifier$sub_refs	_jc_java_lang_reflect_Modifier$sub_refs;
typedef struct _jc_java_lang_reflect_Modifier$sub_nonrefs	_jc_java_lang_reflect_Modifier$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Modifier$refs	_jc_java_lang_reflect_Modifier$refs;
typedef struct _jc_java_lang_reflect_Modifier$nonrefs	_jc_java_lang_reflect_Modifier$nonrefs;
typedef struct _jc_java_lang_reflect_Modifier$object	_jc_java_lang_reflect_Modifier$object;

typedef struct _jc_java_lang_reflect_Modifier$fields_struct	_jc_java_lang_reflect_Modifier$fields_struct;
typedef const struct _jc_java_lang_reflect_Modifier$vmethods	_jc_java_lang_reflect_Modifier$vmethods;
typedef const struct _jc_java_lang_reflect_Modifier$vtable	_jc_java_lang_reflect_Modifier$vtable;
typedef const struct _jc_java_lang_reflect_Modifier$vtype	_jc_java_lang_reflect_Modifier$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Modifier$fields_struct {
	jint	ABSTRACT;
	jint	ALL__5fFLAGS;
	jint	FINAL;
	jint	INTERFACE;
	jint	NATIVE;
	jint	PRIVATE;
	jint	PROTECTED;
	jint	PUBLIC;
	jint	STATIC;
	jint	STRICT;
	jint	SUPER;
	jint	SYNCHRONIZED;
	jint	TRANSIENT;
	jint	VOLATILE;
};
extern _jc_java_lang_reflect_Modifier$fields_struct _jc_java_lang_reflect_Modifier$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Modifier$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_Modifier$object *) _JC_JCNI_ATTR;

// Static methods
extern jboolean _jc_java_lang_reflect_Modifier$method$isAbstract$1cd5ca6bb91d8ecc(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isFinal$8e8ef7d449c3f86e(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isInterface$8c444522b1e3c146(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isNative$66f628b5ecbea9d8(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isPrivate$261685c1800e143b(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isProtected$bb52b8e24e56f1b6(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isPublic$78f9198c5d44531f(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isStatic$11ab11e4d169860e(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isStrict$423f1a01334d10a3(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isSynchronized$b02482e04be5cf74(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isTransient$eed6a1a278d70a1a(_jc_env *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Modifier$method$isVolatile$406ed47e0f5f48d4(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_reflect_Modifier$method$toString$1edd17eb26e44570(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_StringBuffer$object *_jc_java_lang_reflect_Modifier$method$toString$e0ef92f7f91b1ef9(_jc_env *, jint, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_Modifier$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_Modifier$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Modifier$vmethods	java_lang_reflect_Modifier;
};

// Vtype
struct _jc_java_lang_reflect_Modifier$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Modifier$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Modifier$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Modifier$refs {
    _jc_java_lang_reflect_Modifier$sub_refs	java_lang_reflect_Modifier;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Modifier$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Modifier$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Modifier$sub_nonrefs	java_lang_reflect_Modifier;
};

// Object instance structure
struct _jc_java_lang_reflect_Modifier$object {
	_jc_java_lang_reflect_Modifier$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Modifier$vtype	*vtype;
	_jc_java_lang_reflect_Modifier$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Modifier$vtype _jc_java_lang_reflect_Modifier$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Modifier, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Modifier$class_object;

#endif	/* _JC_java_lang_reflect_Modifier_H_ */
